@@ -13,7 +13,11 @@ def _get_version(v):
 
 
 def get_build():
-    total = 0
-    for i in list(time.localtime(time.time()))[:-1]:
-        total += (int(i) * 3)
+    total = ''
+    a = time.localtime(time.time())
+    total += str(a.tm_year)
+    total += str(a.tm_mon)
+    total += str(a.tm_mday)
+    total += str(a.tm_hour)
+    total += str(a.tm_min)
     return total
